@@ -1,10 +1,10 @@
-from parsl.config import Config
-from parsl.providers import SlurmProvider
-from parsl.launchers import SrunLauncher
-from parsl.executors import HighThroughputExecutor
-from parsl.data_provider.globus import GlobusStaging
 from parsl.addresses import address_by_interface
-
+from parsl.config import Config
+from parsl.data_provider.globus import GlobusStaging
+from parsl.executors import HighThroughputExecutor
+from parsl.launchers import SrunLauncher
+from parsl.providers import SlurmProvider
+from parsl.usage_tracking.levels import LEVEL_1
 
 config = Config(
     executors=[
@@ -35,4 +35,5 @@ config = Config(
         )
 
     ],
+    usage_tracking=LEVEL_1,
 )
