@@ -1,14 +1,14 @@
 import logging
 from concurrent.futures import Future
-from typing import Any, Callable, List, Optional, TYPE_CHECKING
+from typing import TYPE_CHECKING, Any, Callable, List, Optional
 
 from parsl.app.futures import DataFuture
-from parsl.data_provider.files import File
 from parsl.data_provider.file_noop import NoOpFileStaging
+from parsl.data_provider.files import File
 from parsl.data_provider.ftp import FTPSeparateTaskStaging
 from parsl.data_provider.http import HTTPSeparateTaskStaging
-from parsl.data_provider.zip import ZipFileStaging
 from parsl.data_provider.staging import Staging
+from parsl.data_provider.zip import ZipFileStaging
 
 if TYPE_CHECKING:
     from parsl.dataflow.dflow import DataFlowKernel
