@@ -1,4 +1,3 @@
-from parsl.channels import LocalChannel
 from parsl.config import Config
 from parsl.data_provider.ftp import FTPInTaskStaging
 from parsl.data_provider.http import HTTPInTaskStaging
@@ -16,7 +15,6 @@ config = Config(
             working_dir="./rsync-workdir/",
             encrypted=True,
             provider=LocalProvider(
-                channel=LocalChannel(),
                 init_blocks=1,
                 max_blocks=1,
                 launcher=SimpleLauncher(),
