@@ -14,7 +14,7 @@ def make_config():
         executors=[
             HighThroughputExecutor(
                 address="127.0.0.1",
-                max_workers=2,
+                max_workers_per_node=2,
                 heartbeat_period=2,
                 heartbeat_threshold=4,
                 encrypted=True,
