@@ -1,11 +1,13 @@
 import logging
 import os
-import parsl
-import pytest
 import socket
 import time
+
+import pytest
 import zmq
 
+import parsl
+
 logger = logging.getLogger(__name__)
 
 
@@ -16,10 +18,11 @@ def this_app():
 
 @pytest.mark.local
 def test_row_counts():
-    from parsl.tests.configs.htex_local_alternate import fresh_config
     import sqlalchemy
     from sqlalchemy import text
 
+    from parsl.tests.configs.htex_local_alternate import fresh_config
+
     if os.path.exists("runinfo/monitoring.db"):
         logger.info("Monitoring database already exists - deleting")
         os.remove("runinfo/monitoring.db")
@@ -41,8 +44,8 @@ def test_row_counts():
     #   the latter is what i'm most suspicious of in my present investigation
 
     # dig out the interchange port...
-    hub_address = parsl.dfk().hub_address
-    hub_zmq_port = parsl.dfk().hub_zmq_port
+    hub_address = parsl.dfk().monitoring.hub_address
+    hub_zmq_port = parsl.dfk().monitoring.hub_zmq_port
 
     # this will send a string to a new socket connection
     with socket.socket(socket.AF_INET, socket.SOCK_STREAM) as s:
