@@ -37,7 +37,6 @@ def fresh_config(run_dir):
         strategy_period=0.1,
         monitoring=MonitoringHub(
                         hub_address="localhost",
-                        hub_port=55055,
         )
     )
 
@@ -107,7 +106,7 @@ def test_stdstream_to_monitoring(stdx, expected_stdx, stream, tmpd_cwd, caplog):
     with engine.begin() as connection:
 
         def count_rows(table: str):
-            result = connection.execute(f"SELECT COUNT(*) FROM {table}")
+            result = connection.execute(sqlalchemy.text(f"SELECT COUNT(*) FROM {table}"))
             (c, ) = result.first()
             return c
 
@@ -121,7 +120,7 @@ def test_stdstream_to_monitoring(stdx, expected_stdx, stream, tmpd_cwd, caplog):
         assert count_rows("try") == 1
 
         # ... and has the expected name.
-        result = connection.execute(f"SELECT task_{stream} FROM task")
+        result = connection.execute(sqlalchemy.text(f"SELECT task_{stream} FROM task"))
         (c, ) = result.first()
 
         if isinstance(expected_stdx, str):
